document.getElementById('analyzeBtn').addEventListener('click', async () => {
await handleUserInput("Analyze this text: ");
});

document.getElementById('summarizeBtn').addEventListener('click', async () => {
await handleUserInput("Summarize this text: ");
});

document.getElementById('translateBtn').addEventListener('click', async () => {
const selectedLanguage = document.getElementById('languages').value;
await handleUserInput(`Translate the following text into ${selectedLanguage}: `);
});

// Funzione per analizzare l'immagine
document.getElementById('describeBtn').addEventListener('click', async () => {
const imgUrl = document.getElementById('imgUrl').value.trim();
if (!imgUrl) {
alert("Please enter an image URL.");
return;
}
await analyzeImage(imgUrl);
});

async function analyzeImage(imgUrl) {
const apikey = await loadApiKey();
if (!apikey) {
alert("No OpenAI API Key found.");
return;
}
const responseMessage = await getChatGPTResponseIMG(imgUrl);
document.getElementById('response').innerText = responseMessage;

// Crea un link per scaricare la risposta
createDownloadLink(responseMessage);
}

// Funzione per gestire l'input dell'utente
async function handleUserInput(prefix) {
// Recupera il testo selezionato
chrome.tabs.query({ active: true, currentWindow: true }, async (tabs) => {
chrome.scripting.executeScript({
target: { tabId: tabs[0].id },
function: () => {
return window.getSelection().toString();
}
}, async (results) => {
const userInput = results[0].result;
if (userInput) {
const apikey = await loadApiKey();
if (!apikey) {
alert("No OpenAI API Key found.");
return;
}
const responseMessage = await getChatGPTResponse(prefix + userInput, apikey);
document.getElementById('response').innerText = responseMessage;

// Crea un link per scaricare la risposta
createDownloadLink(responseMessage);
}
});
});
}

// Funzione per caricare l'API key dal file JSON
async function loadApiKey() {
const response = await fetch(chrome.runtime.getURL('data.json'));
const data = await response.json();
return data.apikey;
}


// Funzione per ottenere la risposta da OpenAI per l'immagine
async function getChatGPTResponseIMG(fileUrl) {
console.log(fileUrl);
const apikey = await loadApiKey(); // Carica la chiave API dal file JSON




try {
const response = await fetch("https://api.openai.com/v1/chat/completions", {
method: "POST",
headers: {
"Content-Type": "application/json",
Authorization: "Bearer " + apikey
},
body: JSON.stringify({
model: "gpt-4o-mini",
messages: [
{
role: "user",
content: [
{
type: "text",
text: "What’s in this image? Provide a detailed description of the image content. If there is any code inside in any programming language you know, write it all down (no excerpts) in the answer and also provide a brief description of what the code does."
},
{
type: "image_url",
image_url: {
url: fileUrl // Usa l'URL fornito come fileUrl
}
}
]
}
]
})
});

if (!response.ok) {
throw new Error("Error while requesting to the API.");
}

const data = await response.json();
if (!data.choices || !data.choices.length || !data.choices[0].message || !data.choices[0].message.content) {
throw new Error("Invalid API response.");
}

var chatGPTResponse = data.choices[0].message.content;
chatGPTResponse = chatGPTResponse.replace(/\*\*(.*?)\*\*/g, "$1");

return chatGPTResponse;
} catch (error) {
console.error(error);
return "An error occurred during the request.";
}
}

// Funzione per ottenere la risposta da OpenAI
async function getChatGPTResponse(userInput, apikey) {
try {
const response = await fetch("https://api.openai.com/v1/chat/completions", {
method: "POST",
headers: {
"Content-Type": "application/json",
Authorization: "Bearer " + apikey
},
body: JSON.stringify({
model: "gpt-4o-mini",
messages: [{ role: "user", content: userInput }]
})
});

if (!response.ok) {
throw new Error("Error while requesting to the API");
}
const data = await response.json();
const chatGPTResponse = data.choices[0].message.content.trim();
return chatGPTResponse;
} catch (error) {
console.error(error);
return "An error occurred during the request.";
}
}

// Funzione per creare un link per scaricare la risposta
function createDownloadLink(content) {
const timestamp = new Date().toISOString().replace(/[:.]/g, '-'); // Formatta il timestamp
const filename = `chatbot_response_${timestamp}.txt`;

const blob = new Blob([content], { type: 'text/plain' });
const url = URL.createObjectURL(blob);

const downloadLink = document.createElement('a');
downloadLink.href = url;
downloadLink.download = filename;
downloadLink.innerText = 'Download Response';
downloadLink.style.display = 'block'; // Mostra il link come blocco
downloadLink.style.marginTop = '10px'; // Margine sopra per una migliore visualizzazione

// Aggiungi il link al div di risposta
const responseDiv = document.getElementById('response');
responseDiv.appendChild(downloadLink);
}